pub struct ConfigurationItem {Show 16 fields
pub version: String,
pub account_id: String,
pub configuration_item_capture_time: DateTime<Utc>,
pub configuration_item_status: String,
pub configuration_state_id: String,
pub arn: String,
pub resource_type: String,
pub resource_id: String,
pub resource_name: Option<String>,
pub aws_region: String,
pub availability_zone: String,
pub resource_creation_time: Option<DateTime<Utc>>,
pub tags: BTreeMap<String, String>,
pub configuration: String,
pub supplementary_configuration: BTreeMap<String, String>,
pub externally_recorded: bool,
}Fields
version: Stringaccount_id: Stringconfiguration_item_capture_time: DateTime<Utc>configuration_item_status: StringOK, ResourceDiscovered, ResourceNotRecorded, ResourceDeleted,
ResourceDeletedNotRecorded.
configuration_state_id: Stringarn: Stringresource_type: Stringresource_id: Stringresource_name: Option<String>aws_region: Stringavailability_zone: Stringresource_creation_time: Option<DateTime<Utc>>configuration: StringThe resource configuration as a JSON string (Config stores this as an escaped JSON document).
supplementary_configuration: BTreeMap<String, String>externally_recorded: boolTrue when this item was recorded via the PutResourceConfig API rather
than discovered from a native fakecloud service. The cross-service
recorder never marks externally-recorded items as deleted (their
lifecycle is owned by the caller, not by native discovery).